# unclick

![Versions](https://img.shields.io/badge/python-3.8+-blue)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Test](https://github.com/albireox/unclick/actions/workflows/test.yml/badge.svg)](https://github.com/albireox/unclick/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/albireox/unclick/branch/main/graph/badge.svg)](https://codecov.io/gh/albireox/unclick)

A reverse parser for [click](https://click.palletsprojects.com).
